@@ -93,6 +93,9 @@ cmd_opt opt;
 #elif EXFAT
 #include "exfatclone.h"
 #define FS "EXFAT"
+#elif F2FS
+#include "f2fsclone.h"
+#define FS "F2FS"
 #elif MINIX
 #include "minixclone.h"
 #define FS "MINIX"
@@ -235,7 +238,8 @@ int main(int argc, char **argv) {
 
 		char bbuffer[16384];
 		unsigned long long i;
-		unsigned long long needed_size, needed_mem;
+		unsigned long long needed_mem = 0;
+		unsigned long long needed_size = 0;
 
 		log_mesg(1, 0, 0, debug, "Initial image hdr - get Super Block from partition\n");
 		log_mesg(0, 0, 1, debug, "Reading Super Block\n");
@@ -370,7 +374,8 @@ int main(int argc, char **argv) {
 		log_mesg(0, 0, 1, debug, "done!\n");
 	} else if (opt.ddd){
 	
-		unsigned long long needed_mem, needed_size;
+		unsigned long long needed_mem = 0;
+		unsigned long long needed_size = 0;
 
 		log_mesg(1, 0, 0, debug, "Initial image hdr - get Super Block from partition\n");
 		log_mesg(1, 0, 1, debug, "Reading Super Block\n");
@@ -815,7 +820,7 @@ int main(int argc, char **argv) {
 
 		int cmp, nx_current = 0;
 		unsigned long long next_block_id = 0;
-		log_mesg(0, 0, 0, debug, "Total block %i\n", image_hdr.totalblock);
+		log_mesg(0, 0, 0, debug, "Total block %llu\n", image_hdr.totalblock);
 		log_mesg(1, 0, 0, debug, "start writing domain log...\n");
 		// write domain log comment and status line
 		dprintf(dfw, "# Domain logfile created by %s v%s\n", EXECNAME, VERSION);
@@ -886,7 +891,7 @@ int main(int argc, char **argv) {
 						log_mesg(0, 1, 1, debug, "%s", bad_sectors_warning_msg);
 				} else if (r_size == 0){ // done for ddd
 				    /// write buffer to target
-				    w_size = write_all(&dfw, buffer, r_size, &opt);
+				    w_size = write_all(&dfw, buffer, rescue_write_size, &opt);
 				    break;
 				} else
 					log_mesg(0, 1, 1, debug, "source read ERROR %s\n", strerror(errno));
