@@ -11,9 +11,12 @@
  * (at your option) any later version.
  */
 
+#define _LARGEFILE64_SOURCE
 #include <sys/param.h>
+#include <sys/types.h>
 #include <xfs/libxfs.h>
 #include <sys/stat.h>
+#include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
@@ -26,6 +29,7 @@
 #include "progress.h"
 #include "fs_common.h"
 
+
 #undef crc32
 char	*EXECNAME = "partclone.xfs";
 extern  fs_cmd_opt fs_opt;
@@ -403,6 +407,10 @@ extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap
 			sk = lseek(source_fd, w_length, SEEK_CUR);
 
 			w_position += w_length;
+			if(w_position > image_hdr.device_size){
+			    w_position = image_hdr.device_size;
+			    size = 0;
+			}
 		    }
 		}
 
